@@ -769,6 +769,7 @@ int rpm_get_file_info(struct rpm *rpmst, struct file_info **files_ret,
         headerGet(rpmst->header, RPMTAG_FILEMODES, filemodes, HEADERGET_MINMEM) != 1 ||
         headerGet(rpmst->header, RPMTAG_FILEVERIFYFLAGS, fileverify, HEADERGET_MINMEM) != 1 ||
         headerGet(rpmst->header, RPMTAG_FILELINKTOS, filelinktos, HEADERGET_MINMEM) != 1) {
+        *count_ret = 0;
         goto cleanup;
     }
 
@@ -962,7 +963,7 @@ int rpm_signature_set_md5(struct rpm *rpmst, unsigned char md5[MD5_DIGEST_LENGTH
     return DRPM_ERR_OK;
 }
 
-/* Reloads the signature to accomodate for changes. */
+/* Reloads the signature to accommodate for changes. */
 int rpm_signature_reload(struct rpm *rpmst)
 {
     rpmst->signature = headerReload(rpmst->signature, RPMTAG_HEADERSIGNATURES);
